@@ -3,14 +3,14 @@ Module: config
 """
 import platform
 
-class Config():
 
+class Config:
     """
     General infos of your SDK
     """
 
     def __init__(self):
-        self.__version = "2.0.9"
+        self.__version = "2.0.10"
         self.__user_agent = "MercadoPago Python SDK v" + self.__version
         self.__product_id = "bc32bpftrpp001u8nhlg"
         self.__tracking_id = "platform:" + platform.python_version()
